| ECB_press_conferences | R Documentation |
A corpus of 260 ECB press conference, split into 4224 paragraphs. The corpus contains a number of docvars indicating the date of the press conference and a measured sentiment based on the Loughran-McDonald lexicon.
ECB_press_conferences
A quanteda::corpus object.
ECB_press_conferences_tokens
docvars(ECB_press_conferences)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.