Learn R Programming

sentopics (version 1.0.0)

LDAvis: Visualize an LDA model using LDAvis

Description

This function call LDAvis to create a dynamic visualization of an estimated topic model.

Usage

LDAvis(x, ...)

Value

Nothing, called for its side effects.

Arguments

x

an LDA model

...

further arguments passed on to LDAvis::createJSON() and LDAvis::serVis().

Details

The CRAN release of LDAvis does not support UTF-8 characters and automatically reorder topics. To solve these two issues, please install the development version of LDAvis from github (devtools::install_github("cpsievert/LDAvis")).

See Also

plot.sentopicsmodel()

Examples

Run this code
lda <- LDA(ECB_press_conferences_tokens)
lda <- fit(lda, 100)
LDAvis(lda)

Run the code above in your browser using DataLab