Computes various coherence based metrics for topic models. It
assesses the quality of estimated topics based on co-occurrences of words.
For best results, consider cleaning the initial tokens object with padding = TRUE.
coherence(
x,
nWords = 10,
method = c("C_NPMI", "C_V"),
window = NULL,
NPMIs = NULL
)A vector or matrix containing the coherence score of each topic.
a model created from the LDA(), JST() or rJST() function and
estimated with fit()
the number of words in each topic used for evaluation.
the coherence method used.
optional. The maximum distance between two tokens to be
considered co-occurring for the coherence measure. Distance is expressed in
token positions. If NULL, use the default window for each coherence
metric (10 for C_NPMI and 110 for C_V). Providing an integer or "boolean"
to this argument will override the default. If "boolean", co-occurences
will simply take place if the two words are present in the same document.
This argument has no effect if the NPMIs argument is also provided.
optional NPMI matrix. If provided, skip the computation of NPMI between words, substantially decreasing computing time.
Olivier Delmarcelle
Currently, only C_NPMI and C_V are documented. The implementation follows Röder & al. (2015). For C_NPMI, the sliding window is 10 whereas it is 110 for C_V.
Röder, M., Both, A., & Hinneburg, A. (2015). Exploring the Space of Topic Coherence Measures. In Proceedings of the Eighth ACM International Conference on Web Search and Data Mining, 399-–408.